@@ -2,7 +2,7 @@
 # Copyright (C) 2011 Rocky Bernstein <rockyb@rubyforge.net>
 use warnings; no warnings 'redefine';
 
-use lib '../../../..';
+use rlib '../../../..';
 
 package Devel::Trepan::CmdProcessor::Command::Eval;
 use if !defined @ISA, Devel::Trepan::CmdProcessor::Command ;
@@ -69,7 +69,7 @@ sub complete($$)
 { 
     my ($self, $prefix) = @_;
     if (!$prefix) {
-	if (0 == index($self->{proc}->{leading_str}, 'eval?')) {
+	if (0 == index($self->{proc}{leading_str}, 'eval?')) {
 	    Devel::Trepan::Util::extract_expression(
 		$self->{proc}->current_source_text());
 	} else {
@@ -84,27 +84,22 @@ sub run($$)
 {
     my ($self, $args) = @_;
     my $proc = $self->{proc};
-    my $text;
+    my $expr;
     my $cmd_name = $args->[0];
     if (1 == scalar @$args) {
-	$text  = $proc->current_source_text();
+	$expr  = $proc->current_source_text();
 	if ('?' eq substr($cmd_name, -1)) {
 	    $cmd_name = substr($cmd_name, 0, length($cmd_name)-1);
-	    $text = Devel::Trepan::Util::extract_expression($text);
-	    $proc->msg("eval: ${text}");
+	    $expr = Devel::Trepan::Util::extract_expression($expr);
+	    $proc->msg("eval: ${expr}");
 	}
     } else {
-	$text = $proc->{cmd_argstr};
+	$expr = $proc->{cmd_argstr};
     }
     {
 	my $opts->{return_type} = parse_eval_suffix($cmd_name);
-	my $dbgr = $proc->{dbgr};
 	no warnings 'once';
-	$DB::eval_str = $dbgr->evalcode($text);
-	$DB::eval_opts = $opts;
-	$DB::result_opts = $opts;
-	$proc->{DB_running} = 2;
-	$proc->{leave_cmd_loop} = 1;
+	$proc->evaluate($expr, $opts);
     }
 }
 
