@@ -2,10 +2,10 @@
 # Copyright (C) 2011 Rocky Bernstein <rocky@cpan.org>
 
 use warnings; no warnings 'redefine';
-use lib '../../../..';
+use rlib '../../../..';
 
 package Devel::Trepan::CmdProcessor::Command::Macro;
-use English;
+use English qw( -no_match_vars );
 use if !defined @ISA, Devel::Trepan::CmdProcessor::Command ;
 unless (defined(@ISA)) {
     eval "use constant CATEGORY   => 'support';";
