@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Copyright (C) 2011 Rocky Bernstein <rocky@cpan.org>
 use warnings; no warnings 'redefine'; no warnings 'once';
-use lib '../../../../..';
+use rlib '../../../../..';
 
 package Devel::Trepan::CmdProcessor::Command::Set::EvalDisplay;
 
@@ -32,7 +32,7 @@ sub run($$)
 	$proc->errmsg("Expecting either 'tidy' or 'dumper', got ${evaltype}");
 	return;
     }
-    $proc->{commands}->{show}->run(['show', 'evaldisplay']);
+    $proc->{commands}{show}->run(['show', 'evaldisplay']);
 }
 
 unless (caller) {
