@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
 # Copyright (C) 2011 Rocky Bernstein <rocky@cpan.org> 
 use strict; use warnings;
-use lib '../../..';
+use rlib '../../..';
 use Devel::Trepan::DB::Sub;
 use Devel::Trepan::Complete;
 
 package Devel::Trepan::CmdProcessor;
-use English;
+use English qw( -no_match_vars );
 
 sub adjust_frame($$$)
 {
@@ -89,7 +89,7 @@ sub frame_setup($$$)
 sub filename($)
 {
     my $self = shift;
-    $self->{frame}->{file};
+    $self->{frame}{file};
 }
 
 sub get_frame($$$) 
@@ -114,7 +114,7 @@ sub get_frame($$$)
     my $frames = $self->{frames};
     unless ($frames->[$frame_num]) {
 	my @new_frames = $self->{dbgr}->backtrace(0);
-	$self->{frames}->[$frame_num] = $new_frames[$frame_num];
+	$self->{frames}[$frame_num] = $new_frames[$frame_num];
     }
     $self->{frame} = $frames->[$frame_num];
     return ($self->{frame}, $frame_num);
@@ -123,7 +123,7 @@ sub get_frame($$$)
 sub line($)
 {
     my $self = shift;
-    $self->{frame}->{line};
+    $self->{frame}{line};
 }
 
 sub print_stack_entry()
